@@ -1,6 +1,5 @@
 package org.gcube.portlets.user.td.gwtservice.shared.source;
 
-import org.gcube.portlets.user.td.gwtservice.shared.source.Source;
 
 
 
@@ -18,15 +17,13 @@ public class SDMXRegistrySource implements Source {
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
 	public String getId() {
-		return "SDMXRegistry";
+		return SourceType.SDMXRegistry.toString();
 	}
 
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
 	public String getName() {
 		return "SDMX Registry source";
 	}
@@ -34,7 +31,6 @@ public class SDMXRegistrySource implements Source {
 	/**
 	 * {@inheritDoc}
 	 */
-	@Override
 	public String getDescription() {
 		return "Select this source if you want to retrive document from SDMX Registry";
 	}
